export default {
  data() {
    return {
      total: 20,
      loading: false,
      tableData: [],
      tableOptions: {
        sortTable: true,
        maxHeight: 'calc(100vh - 406px)',
        height: 'calc(100vh - 406px)'
      },
      columns: [
        {
          label: '序号',
          index: true
        },
        {
          label: '结算单编号',
          prop: 'moduleNumber',
          showTooltip: true,
          width: 150
        },
        {
          label: '业务编号',
          prop: 'businessNumber',
          showTooltip: true,
          width: 150
        },
        {
          label: '项目名称',
          showTooltip: true,
          prop: 'businessName',
          width: 150
        },
        {
          label: '主企业名称',
          prop: 'supplierName',
          width: 120,
          showTooltip: true
        },
        {
          label: '核心企业名称',
          prop: 'customerName',
          width: 120,
          showTooltip: true
        },
        {
          label: '贸易平台',
          prop: 'platformName',
          showTooltip: true
        },
        {
          label: '结算日期',
          prop: 'settlementDate',
          showTooltip: true,
          render: (h, row) => {
            return <div>{ row.settlementDate ? row.settlementDate.split(' ')[0] : '' }</div>
          }
        },
        {
          label: '结算金额（元）',
          prop: 'settlementAmount',
          showTooltip: true
        },
        {
          label: '当前阶段',
          prop: 'taskName',
          showTooltip: true
        },
        {
          label: '执行人',
          prop: 'executor',
          showTooltip: true
        },
        {
          label: '状态',
          prop: 'status.name',
          showTooltip: true
        },
        {
          label: '操作',
          show: true,
          render: (h, row) => {
            const btnList = [
              {
                msg: '时间进度轴',
                icon: 'iconfont icon-timeAxis',
                tabPower: ['all', 'pending'],
                category: 'timeAxis'
              },
              {
                msg: '编辑',
                icon: 'iconfont icon-xiugai',
                tabPower: ['pending'],
                category: 'edit',
              },
              {
                msg: '查看',
                icon: 'iconfont icon-Magnifier',
                power: 'viewBill',
                tabPower: ['all'],
                category: 'see'
              },
              {
                msg: '结算单下载',
                icon: 'iconfont icon-xiazai',
                power: 'downloadAllSettlementFile',
                tabPower: ['all'],
                rowPower: ['已完成'],
                category: 'downloadContract'
              },
              {
                msg: '出证文件下载',
                icon: 'iconfont icon-xiazai',
                power: 'downloadReport',
                tabPower: ['all'],
                rowPower: ['已完成'],
                category: 'downloadFile'
              }
            ]
            const options = btnList.map(item => {
              return (
                this.tablePower({ item, tab: this.activeName, row }) &&
                <el-tooltip class='item' effect='dark' content={item.msg} placement='top' >
                  <span class='table-icon-box'>
                    <i class={item.icon} onClick={() => { this.handlerOperate(item.category, row) }}></i>
                  </span>
                </el-tooltip>
              )
            })
            return <div>{ options }</div>
          },
          width: 200
        }
      ]
    }
  },
  computed: {
    tablePower() {
      return ({ item, tab, row }) => {
        const { tabPower, rowPower, power } = item
        if(power && !this.btnPermission.includes(power)) {
          return false
        }
        if(rowPower && (!row.status || !row.status.name || !rowPower.includes(row.status.name))) {
          return false
        }
        if(tabPower && !tabPower.includes(tab)) {
          return false
        }
        return true
      }
    }
  }
}
